@@ -1,5 +1,3 @@
-from typing import List
-
 from dbnd import parameter
 from dbnd._core.task import Config
 
@@ -35,3 +33,12 @@ class AirflowTrackingConfig(Config):
     max_xcom_length = parameter(
         default=10, description="The amount of xcom values to track, per operator"
     )[int]
+
+    # This shouldn't be set to None. In webserver None evaluates to True.
+    af_with_monitor = parameter(
+        default=True, description="Activate when airflow monitor is not in use",
+    )[bool]
+
+    sql_reporting = parameter(
+        default=True, description="Enable targets reporting from sql queries",
+    )[bool]
